/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef _AUDIOCONFIG_H
#define _AUDIOCONFIG_H

#include <jsoncpp/json/json.h>

#include <cstdint>

#include "audiodatastream.h"
#include "util.h"

struct _AudioConfig {
    // 音频输入来源类型
    enum InputSource { DEFAULT_MIC, STREAM, PCM_FILE, RAW_DATA } input_source;

    // 音频输出目标类型
    enum OutputTarget {
        PCM_DATA,
        DEFAULT_SPEAKER,
        PCM_OUTPUT_FILE
    } output_target;

    // 输入相关字段
    union {
        // PCM文件路径
        const char* pcm_file_path;

        // 原始数据
        struct {
            const uint8_t* data;
            uint32_t length;
        } raw_data;

        AudioDataStream* audio_data_stream;
    };

    // 输出相关字段
    union {
        // PCM输出文件路径
        const char* output_pcm_file_path;
    };

    // 输入音频格式设置
    int sample_rate;
    // 输出音频格式设置
    int speed;   // 语速，可选值：[0-100]，默认为50
    int volume;  // 音量，可选值：[0-100]，默认为50
    int pitch;   // 音高，可选值：[0-100]，默认为50
};

std::string audioConfigToJson(const _AudioConfig& config);

_AudioConfig* audio_config_create_default();

#endif
