/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "_speechsynthesizersession.h"

namespace kyai {
namespace core {
namespace speech {

int _SpeechSynthesizerSession::init() {
    int ret = serviceProxy_.connectToServer();
    if (ret == -1) {
        return AiSdkCommonErrorCode::AISDK_RUNTIME_ERROR;
    }
    int errorCode = 0;
    const std::string jsonStringConfig = modelConfigToJson(modelConfig_);
    sessionId_ =
        serviceProxy_.initSynthesizer(errorCode, jsonStringConfig.c_str());
    if (sessionId_ == -1) {
        return errorCode;
    }
    return AiSdkCommonErrorCode::AISDK_NO_ERROR;
}

void _SpeechSynthesizerSession::destroySynthesizer() {
    serviceProxy_.destroySynthesizer(sessionId_);
}

void _SpeechSynthesizerSession::setSynthesizerAudioConfig(
    _AudioConfig *config) {
    if (config == nullptr) {
        return;
    }
    audioConfig_ = config;

    const std::string jsonStringConfig = audioConfigToJson(*config);
    serviceProxy_.setSynthesizerAudioConfig(sessionId_, jsonStringConfig);
}

void _SpeechSynthesizerSession::setSynthesizerResultCallback(
    SpeechSynthesisResultCallback callback, void *userData) {
    serviceProxy_.setSynthesizerCallback(callback, userData);
}

void _SpeechSynthesizerSession::synthesizeTextOnce(const char *text,
                                                   uint32_t textLength) {
    serviceProxy_.synthesizeTextOnce(sessionId_, text, textLength);
}

void _SpeechSynthesizerSession::synthesizeTextContinuous(const char *text,
                                                         uint32_t textLength) {
    serviceProxy_.synthesizeTextContinuous(sessionId_, text, textLength);
}

int _SpeechSynthesizerSession::stopSpeaking() {
    return serviceProxy_.stopSpeaking(sessionId_);
}

void _SpeechSynthesizerSession::setSynthesizerModelConfig(
    const SpeechModelConfig &config) {
    modelConfig_ = config;
}
}  // namespace speech
}  // namespace core
}  // namespace kyai
