#include "coreaispeechserver.h"

namespace kyai::core::speech {

const std::string serverUnixPath = "unix:path=/tmp/.kylin-ai-runtime-unix/" +
                                   std::to_string(getuid()) +
                                   "/core-speech.sock";

CoreAiSpeechServer &CoreAiSpeechServer::getInstance() {
    static CoreAiSpeechServer instance{};
    return instance;
}

CoreAiSpeechServer::CoreAiSpeechServer() { init(serverUnixPath); }

CoreAiSpeechServer::~CoreAiSpeechServer() { destroy(); }

void CoreAiSpeechServer::init(const std::string &unixPath) {
    GError *error = nullptr;
    connection_ = g_dbus_connection_new_for_address_sync(
        unixPath.c_str(), G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_CLIENT,
        nullptr, /* GDBusAuthObserver */
        nullptr, /* GCancellable */
        &error);
    if (connection_ == nullptr) {
        g_printerr("Error connecting to D-Bus address %s: %s\n",
                   unixPath.c_str(), error->message);
        g_error_free(error);
    }
}

void CoreAiSpeechServer::destroy() {
    if (connection_ != nullptr) {
        g_object_unref(connection_);
    }
}

}  // namespace kyai::core::speech
